function [K_BKMK] = Iteration_K_BKMK(sigma_ai, n_i, k, N_D, N_quer, D_mmin, eps)

%Funktion bestimmt den Betriebsfestigkeitsfaktor K_BKMK nach dem Verfahren 
%Miner konsequent, vgl. Kapitel 4.4.3.5.2, FKM-Richtlinie 6. Aufl. 2012.
%
%Zur iterativen Bestimmung von A_kon, und damit von K_BKMK, wird zunchst
%ein Startwert fr die quivalenzamplitude mit dem Verfahren Miner
%elementar berechnet, Gleichung 4.4.56. 
%
%A_kon wird anschlieend mit einer Genauigkeit fr die 
%quivalenzamplitude von 1/10 des Kollektivhchstwert bestimmt. Reicht 
%diese Genauigkeit nicht aus, um die geforderte Genauigkeit fr die 
%Lebensdauer eps zu erreichen, dann wird die Berechnung mit einer
%fortwhrenden Verfeinerung der quivalenzamplitude mit dem Faktor 1/10 
%je Schleifendurchlauf wiederholt.
%
%Die Funktion meldet einen Fehler und gibt den Wert K_BKMK = -1 zurck,
%wenn keine Kovergenz erreicht wurde.
%
%Eingaben:
%sigma_ai = Kollektivamplituden passend zu n_i (Spaltenvektor)
%n_i      = Kollektivstufenhufigkeiten passend zu sigma_ai (Spaltenvektor)
%k        = Whlerlinienneigung nach Kap. 4.4.3.4
%N_D      = Knickpunktzyklenzahl der Bauteil-Whlerlinie nach Kap. 4.4.3.4
%N_quer   = Geforderte Zyklenzahl nach Kapitel 4.1.3.1
%D_mmin   = Untergrenze der effektiven Miner-Summe nach Tab. 4.4.4
%eps      = Iterationsgenauigkeit fr die geforderte Lebensdauer, eps = 1 --> Auf ein Schwingspiel genau
%
%Ausgaben:
%K_BKMK = Betriebsfestigkeitsfaktor nach dem Verfahren Miner konsequent
%
%Aufrufbeispiel:
%[K_BKMK] = Iteration_K_BKMK(sigma_ai, n_i, k, N_D, N_quer, D_mmin, eps)
%
%nderungshistorie:
%02. November 2016:
%   Dr.-Ing. C. Mller
%       Erstausgabe


%Berechne Startwert fr Iteration sigma_aquschlange, vgl. Gleichung 4.4.56:
[sigma_aquschlange] = sigma_aquschlangestart(sigma_ai, n_i, k, N_D, N_quer, D_mmin);

%Wenn eine quivalenzamplitude als Startwert berechnet wurde, die grer
%als der Kollektivhchstwert ist, dann soll die erste Amplitude unter dem
%Kollektivhchstwert verwendet werden. 
%
%Hinweis:
%Die quivalenzamplitude kann nicht grer als der Kollektivhchstwert
%sein. Das Rechteckkollektiv mit Kollektivhchstwert ist die denkbar
%hrteste Beanspruchung.
if sigma_aquschlange > sigma_ai(1)
    sigma_aquschlange = sigma_ai(2);
end


%Fge sigma_ai und n_i die fiktive Nullstufe hinzu, vgl. S. 105 unten 
%rechts:
j        = length(n_i);
sigma_ai = [sigma_ai; 0];
n_i      = [n_i; 0];


%Bestimme iterative Lsung A_kon, vgl. Kapitel 4.4.3.5.2:
%Initialisiere Steuerungsparamater:
exitflag   = 0;
steigend   = 0;
fallend    = 0;
sigmadelta = sigma_aquschlange / 10;

%Die while-Schliefe wird erst verlassen, wenn N_quer = N_schlange mit
%Genauigkeit eps entspricht, vgl. 106 oben links:
while exitflag == 0
    %Bestimme erste Kollektivstufe unterhalb von sigma_aquschlange, vgl. 
    %Seite 105 unten rechts:
    m = 2;
    for i=1:length(sigma_ai)
        if sigma_ai(i) < sigma_aquschlange
            m = i;
            break
        end
    end
    
    %Berechne Z1, vgl. Gleichung 4.4.58:
    Z1 = (sigma_aquschlange/sigma_ai(1))^(k-1) - (sigma_ai(m)/sigma_ai(1))^(k-1);
    
    %Berechne N1, vgl. Gleichung 4.4.58:
    N1 = 0;
    for i=1:m-1
        N1 = N1 + n_i(i)/N_quer*(sigma_ai(i)/sigma_ai(1))^k;
    end
    
    %Berechne A_kon, vgl. Gleichung 4.4.58:
    A_kon = 0;
    for nu=m:j
        %Berechne Z2, vgl. Gleichung 4.4.58:
        Z2 = (sigma_ai(nu)/sigma_ai(1))^(k-1) - (sigma_ai(nu+1)/sigma_ai(1))^(k-1);
        
        %Berechne N2, vgl. Gleichung 4.4.58:
        N2 = 0;
        for i=1:nu
            N2 = N2 + n_i(i)/N_quer*(sigma_ai(i)/sigma_ai(1))^k;
        end
        
        A_kon = A_kon + Z2/N2;
    end
    
    A_kon = (Z1/N1 + A_kon)*(sigma_ai(1)/sigma_aquschlange)^(k-1);
    
    %Bestimme D_m, vgl. Gleichung 4.4.51 mit darunterstehender 
    %Maximumbediingung:
    D_m = 2 / A_kon^0.25;

    if D_m < D_mmin
        D_m = D_mmin;
    elseif D_m > 1
        D_m = 1;
    end
    
    
    %Berechne N_schlange, vgl. Gleichung 4.4.57:
    N_schlange = A_kon * N_D * D_m * (sigma_aquschlange/sigma_ai(1))^k;
    
    
    %berprfe Abbruchkriterium:
    %Abbruchkriterium erreicht:
    if abs(N_schlange - N_quer) < eps %Abbruchkriterium erreicht
        exitflag = 1;
        
    %Mit dem aktuellen sigmadelta geht es nicht besser, verkleinere sigmadelta:    
    elseif (N_schlange < N_quer && fallend == 1) || (N_schlange > N_quer && steigend == 1)
        sigmadelta = sigmadelta / 10;
        steigend   = 0;
        fallend    = 0;
        
    %sigma_aquschlange zu gro, wurde noch nicht verkleinert    
    elseif N_schlange > N_quer
        sigma_aquschlange = sigma_aquschlange - sigmadelta;
        fallend           = 1;
        
    %sigma_aquschlange zu klein, wurde noch nicht vergrert (wenn der
    %Startwert nach dem Verfahren Miner elementar geschtzt wird, dann ist
    %dieser immer grer-gleich der quivalenzamplitude nach dem Verfahren
    %Miner konsequent:
    elseif N_schlange < N_quer
        sigma_aquschlange = sigma_aquschlange + sigmadelta;
        steigend          = 1;
        
    %Es konnte keine Lsung gefunden werden, z.B. wenn eps sehr klein
    %gewhlt wurde:
    else
        exitflag          = -1;
        sigma_aquschlange = -1;
        errordlg('Keine Lsung fr K_{BKMK} gefunden! eps vergrern!')
    end
end


%Berechne K_BKMK:
if exitflag == 1
    K_BKMK = (A_kon*N_D*D_m / N_quer)^(1/k);
    if K_BKMK < 1
        K_BKMK = 1;
    end
else
    K_BKMK = -1;
end